@@ -1,8 +1,8 @@
 #!/usr/bin/python3
 
-
+from contextlib import suppress
 from lintian_brush.fixer import report_result, LintianIssue
-from lintian_brush.rules import (
+from debmutate._rules import (
     dh_invoke_drop_with,
     RulesEditor,
     )
@@ -22,15 +22,12 @@ def drop_quilt_with(line, target):
     return newline
 
 
-try:
-    with open('debian/source/format', 'r') as f:
-        if f.read().strip() == '3.0 (quilt)':
-            with RulesEditor() as updater:
-                if rules_find_patches_directory(
-                        updater.makefile) in ('debian/patches', None):
-                    updater.legacy_update(command_line_cb=drop_quilt_with)
-except FileNotFoundError:
-    pass
+with suppress(FileNotFoundError), open('debian/source/format', 'r') as f:
+    if f.read().strip() == '3.0 (quilt)':
+        with RulesEditor() as updater:
+            if rules_find_patches_directory(
+                    updater.makefile) in ('debian/patches', None):
+                updater.legacy_update(command_line_cb=drop_quilt_with)
 
 
 report_result(
