@@ -14,6 +14,9 @@ if not net_access_allowed():
     sys.exit(0)
 
 
+version_changed = None
+
+
 with ChangelogEditor() as editor:
     if editor.changelog[-1].bugs_closed:
         sys.exit(0)
@@ -36,6 +39,8 @@ with ChangelogEditor() as editor:
             continue
 
         if 'Initial release' in line:
+            if not line.rstrip().endswith('.'):
+                line = line.rstrip() + '.'
             editor.changelog[-1]._changes[i] = line + (
                 " Closes: #%s" % ', '.join(
                     [str(bugno) for (bugno, kind) in wnpp_bugs]))
