@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 
-from lintian_brush.fixer import report_result
+from lintian_brush.fixer import report_result, fixed_lintian_tag
 from lintian_brush.systemd import systemd_service_files, SystemdServiceEditor
 import os
 
@@ -11,8 +11,10 @@ for path in systemd_service_files():
             base, ext = os.path.splitext(alias)
             if ext != required_ext:
                 updater.file['Unit']['Alias'][i] = base + required_ext
+                fixed_lintian_tag(
+                    'source',
+                    'systemd-service-alias-without-extension',
+                    '%s' % path)
 
 
-report_result(
-    'Use proper extensions in Alias in systemd files.',
-    fixed_lintian_tags=['systemd-service-alias-without-extension'])
+report_result('Use proper extensions in Alias in systemd files.')
