@@ -1566,6 +1566,17 @@ def main(argv=None):  # noqa: C901
         upstream_branch = Branch.open(upstream_info.branch_url)
         upstream_subpath = upstream_info.branch_subpath
     else:
+        if not wt.has_filename(os.path.join(subpath, 'debian')):
+            report_fatal(
+                code='debian-directory-exists',
+                description="%s: A debian directory already exists. " % e.path,
+                hint=("Run lintian-brush instead or "
+                      "specify --force-new-directory."),
+            )
+            return 1
+        logging.info(
+            'No upstream repository specified, using upstream source in %s',
+            wt.abspath(subpath))
         upstream_branch = wt.branch
         upstream_subpath = subpath
 
