@@ -17,9 +17,15 @@
 
 """Section handling."""
 
+import os
 import re
 
-NAME_SECTION_MAPPINGS_PATH = "/usr/share/lintian/data/fields/name_section_mappings"
+
+from .lintian import LINTIAN_DATA_PATH
+
+
+NAME_SECTION_MAPPINGS_PATH = os.path.join(
+    LINTIAN_DATA_PATH, "fields/name_section_mappings")
 
 
 def get_name_section_mappings():
@@ -27,17 +33,17 @@ def get_name_section_mappings():
 
     with open(NAME_SECTION_MAPPINGS_PATH, "r") as f:
         for line in f:
-            try:
-                (regex, section) = line.split("=>")
-            except ValueError:
-                pass
-            else:
-                regexes.append((re.compile(regex.strip()), section.strip()))
+            if line.startswith('#'):
+                continue
+            if not line.strip():
+                continue
+            (regex, section) = line.split("=>")
+            regexes.append((re.compile(regex.strip()), section.strip()))
     return regexes
 
 
 def find_expected_section(regexes, name):
     for regex, section in regexes:
-        if regex.search(name):
+        if regex.match(name):
             return section
     return None
