@@ -44,13 +44,12 @@ class FixerTestCase(unittest.TestCase):
         self._fixer_name = fixer_name
         self._test_name = name
         self._path = path
-        self._testdir = None
-        self._tempdir = None
         self.maxDiff = None
         super(FixerTestCase, self).__init__()
 
     def setUp(self):
         self._tempdir = tempfile.mkdtemp()
+        self.addCleanup(shutil.rmtree, self._tempdir)
         self._testdir = os.path.join(self._tempdir, "testdir")
 
         def ignore(src, names):
@@ -67,11 +66,6 @@ class FixerTestCase(unittest.TestCase):
     def __str__(self):
         return "fixer test: %s for %s" % (self._test_name, self._fixer_name)
 
-    def tearDown(self):
-        shutil.rmtree(self._tempdir)
-        self._testdir = None
-        self._tempdir = None
-
     def runTest(self):
         xfail_path = os.path.join(self._path, "xfail")
         if os.path.exists(xfail_path):
@@ -95,7 +89,7 @@ class FixerTestCase(unittest.TestCase):
         env["NET_ACCESS"] = "disallow"
         env["MINIMUM_CERTAINTY"] = "possible"
         env["PYTHONPATH"] = ':'.join(
-            [os.path.dirname(os.path.dirname(__file__))]
+            [os.path.dirname(os.path.dirname(os.path.dirname(__file__)))]
             + sys.path)
         env_path = os.path.join(self._path, "env")
         if os.path.exists(env_path):
@@ -107,7 +101,7 @@ class FixerTestCase(unittest.TestCase):
             self._fixer.script_path, cwd=self._testdir, stdout=subprocess.PIPE,
             env=env
         )
-        (stdout, err) = p.communicate("")
+        (stdout, err) = p.communicate(b"")
         self.assertEqual(p.returncode, 0)
         out_path = os.path.join(self._path, "out")
         p = subprocess.Popen(
@@ -124,7 +118,7 @@ class FixerTestCase(unittest.TestCase):
             ],
             stdout=subprocess.PIPE,
         )
-        (diff, stderr) = p.communicate("")
+        (diff, stderr) = p.communicate(b"")
         self.assertIn(
             p.returncode, (0, 1),
             "Unexpected exit code %d" % p.returncode)
@@ -228,7 +222,8 @@ if __name__ == "__main__":
     fixers = list(available_lintian_fixers())
     if args.fixer:
         try:
-            fixers = select_fixers(fixers, args.fixer, args.exclude)
+            fixers = select_fixers(
+                fixers, names=args.fixer, exclude=args.exclude)
         except KeyError as e:
             print("Selected fixer %s does not exist." % (
                 e.args[0]), file=sys.stderr)
